TextStyles class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- textBoldBig → const TextStyle
- textBoldMedium → const TextStyle
- textBoldSmall → const TextStyle
- textRegular → const TextStyle
- textRegularLight → const TextStyle
- textSmall → const TextStyle
- titleMedium → const TextStyle
- titleSmall → const TextStyle